summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorSimon Rettberg2015-12-14 17:39:31 +0100
committerSimon Rettberg2015-12-14 17:39:31 +0100
commitcff5750eaa624c777878b124578a999bff930081 (patch)
tree5c48383bafd9c8f816d85bbaad59a642e77b7f1e
parent[SSPS] Patch ipxe compile time config (disable unneeded features) (diff)
downloadsetup-scripts-cff5750eaa624c777878b124578a999bff930081.tar.gz
setup-scripts-cff5750eaa624c777878b124578a999bff930081.tar.xz
setup-scripts-cff5750eaa624c777878b124578a999bff930081.zip
[SSPS] Include patch for proper ipxe version
-rw-r--r--satellit_installer/static_files/ipxe.patch134
1 files changed, 63 insertions, 71 deletions
diff --git a/satellit_installer/static_files/ipxe.patch b/satellit_installer/static_files/ipxe.patch
index 0fdec28..87ff25a 100644
--- a/satellit_installer/static_files/ipxe.patch
+++ b/satellit_installer/static_files/ipxe.patch
@@ -1,90 +1,82 @@
+diff --git a/src/config/branding.h b/src/config/branding.h
+index 73f00af..7a30111 100644
+--- a/src/config/branding.h
++++ b/src/config/branding.h
+@@ -24,7 +24,7 @@ FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );
+ * "iPXE".
+ *
+ */
+-#define PRODUCT_NAME ""
++#define PRODUCT_NAME "OpenSLX iPXE+PXELINUX4 Hybrid"
+ #define PRODUCT_SHORT_NAME "iPXE"
+ #define PRODUCT_URI "http://ipxe.org"
+
diff --git a/src/config/console.h b/src/config/console.h
-index 04be02d..2d3d3fa 100644
+index 9f770d0..a4f7b60 100644
--- a/src/config/console.h
+++ b/src/config/console.h
-@@ -23,7 +23,7 @@ FILE_LICENCE ( GPL2_OR_LATER );
- //#define CONSOLE_VMWARE /* VMware logfile console */
- //#define CONSOLE_DEBUGCON /* Debug port console */
+@@ -53,7 +53,7 @@ FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );
+ //#define CONSOLE_PC_KBD /* Direct access to PC keyboard */
--#define KEYBOARD_MAP us
-+#define KEYBOARD_MAP de
-
- #define LOG_LEVEL LOG_NONE
+ /* Keyboard map (available maps in hci/keymap/) */
+-#define KEYBOARD_MAP us
++#define KEYBOARD_MAP de
+ /* Control which syslog() messages are generated.
+ *
diff --git a/src/config/general.h b/src/config/general.h
-index 9f0bb52..bc904c9 100644
+index ee15f6b..da39a1a 100644
--- a/src/config/general.h
+++ b/src/config/general.h
-@@ -24,14 +24,14 @@ FILE_LICENCE ( GPL2_OR_LATER );
- * "iPXE".
+@@ -63,11 +63,11 @@ FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );
*
*/
--#define PRODUCT_NAME ""
-+#define PRODUCT_NAME "OpenSLX"
- #define PRODUCT_SHORT_NAME "iPXE"
- /*
- * Timer configuration
- *
- */
--#define BANNER_TIMEOUT 20 /* Tenths of a second for which the shell
-+#define BANNER_TIMEOUT 5 /* Tenths of a second for which the shell
- banner should appear */
-
- /*
-@@ -65,18 +65,18 @@ FILE_LICENCE ( GPL2_OR_LATER );
- *
- */
-
--//#undef SANBOOT_PROTO_ISCSI /* iSCSI protocol */
--//#undef SANBOOT_PROTO_AOE /* AoE protocol */
--//#undef SANBOOT_PROTO_IB_SRP /* Infiniband SCSI RDMA protocol */
--//#undef SANBOOT_PROTO_FCP /* Fibre Channel protocol */
-+#undef SANBOOT_PROTO_ISCSI /* iSCSI protocol */
-+#undef SANBOOT_PROTO_AOE /* AoE protocol */
-+#undef SANBOOT_PROTO_IB_SRP /* Infiniband SCSI RDMA protocol */
-+#undef SANBOOT_PROTO_FCP /* Fibre Channel protocol */
+-//#undef SANBOOT_PROTO_ISCSI /* iSCSI protocol */
+-//#undef SANBOOT_PROTO_AOE /* AoE protocol */
+-//#undef SANBOOT_PROTO_IB_SRP /* Infiniband SCSI RDMA protocol */
+-//#undef SANBOOT_PROTO_FCP /* Fibre Channel protocol */
+-//#undef SANBOOT_PROTO_HTTP /* HTTP SAN protocol */
++#undef SANBOOT_PROTO_ISCSI /* iSCSI protocol */
++#undef SANBOOT_PROTO_AOE /* AoE protocol */
++#undef SANBOOT_PROTO_IB_SRP /* Infiniband SCSI RDMA protocol */
++#undef SANBOOT_PROTO_FCP /* Fibre Channel protocol */
++#undef SANBOOT_PROTO_HTTP /* HTTP SAN protocol */
/*
+ * HTTP extensions
+@@ -81,9 +81,9 @@ FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );
* 802.11 cryptosystems and handshaking protocols
*
*/
--#define CRYPTO_80211_WEP /* WEP encryption (deprecated and insecure!) */
--#define CRYPTO_80211_WPA /* WPA Personal, authenticating with passphrase */
--#define CRYPTO_80211_WPA2 /* Add support for stronger WPA cryptography */
-+#undef CRYPTO_80211_WEP /* WEP encryption (deprecated and insecure!) */
-+#undef CRYPTO_80211_WPA /* WPA Personal, authenticating with passphrase */
-+#undef CRYPTO_80211_WPA2 /* Add support for stronger WPA cryptography */
+-#define CRYPTO_80211_WEP /* WEP encryption (deprecated and insecure!) */
+-#define CRYPTO_80211_WPA /* WPA Personal, authenticating with passphrase */
+-#define CRYPTO_80211_WPA2 /* Add support for stronger WPA cryptography */
++#undef CRYPTO_80211_WEP /* WEP encryption (deprecated and insecure!) */
++#undef CRYPTO_80211_WPA /* WPA Personal, authenticating with passphrase */
++#undef CRYPTO_80211_WPA2 /* Add support for stronger WPA cryptography */
/*
* Name resolution modules
-@@ -107,21 +107,21 @@ FILE_LICENCE ( GPL2_OR_LATER );
- *
- */
- #define AUTOBOOT_CMD /* Automatic booting */
--#define NVO_CMD /* Non-volatile option storage commands */
-+#undef NVO_CMD /* Non-volatile option storage commands */
- #define CONFIG_CMD /* Option configuration console */
- #define IFMGMT_CMD /* Interface management commands */
--#define IWMGMT_CMD /* Wireless interface management commands */
--#define FCMGMT_CMD /* Fibre Channel management commands */
-+#undef IWMGMT_CMD /* Wireless interface management commands */
-+#undef FCMGMT_CMD /* Fibre Channel management commands */
- #define ROUTE_CMD /* Routing table management commands */
- #define IMAGE_CMD /* Image management commands */
- #define DHCP_CMD /* DHCP management commands */
--#define SANBOOT_CMD /* SAN boot commands */
-+#undef SANBOOT_CMD /* SAN boot commands */
- #define MENU_CMD /* Menu commands */
--#define LOGIN_CMD /* Login command */
--#define SYNC_CMD /* Sync command */
-+#undef LOGIN_CMD /* Login command */
-+#undef SYNC_CMD /* Sync command */
- //#define NSLOOKUP_CMD /* DNS resolving command */
--//#define TIME_CMD /* Time commands */
--//#define DIGEST_CMD /* Image crypto digest commands */
-+#undef TIME_CMD /* Time commands */
-+#undef DIGEST_CMD /* Image crypto digest commands */
- //#define LOTEST_CMD /* Loopback testing commands */
- //#define VLAN_CMD /* VLAN commands */
- //#define PXE_CMD /* PXE commands */
+@@ -119,15 +119,15 @@ FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );
+ #define NVO_CMD /* Non-volatile option storage commands */
+ #define CONFIG_CMD /* Option configuration console */
+ #define IFMGMT_CMD /* Interface management commands */
+-#define IWMGMT_CMD /* Wireless interface management commands */
+-#define FCMGMT_CMD /* Fibre Channel management commands */
++#undef IWMGMT_CMD /* Wireless interface management commands */
++#undef FCMGMT_CMD /* Fibre Channel management commands */
+ #define ROUTE_CMD /* Routing table management commands */
+ #define IMAGE_CMD /* Image management commands */
+ #define DHCP_CMD /* DHCP management commands */
+-#define SANBOOT_CMD /* SAN boot commands */
++#undef SANBOOT_CMD /* SAN boot commands */
+ #define MENU_CMD /* Menu commands */
+-#define LOGIN_CMD /* Login command */
+-#define SYNC_CMD /* Sync command */
++#undef LOGIN_CMD /* Login command */
++#undef SYNC_CMD /* Sync command */
+ //#define NSLOOKUP_CMD /* DNS resolving command */
+ //#define TIME_CMD /* Time commands */
+ //#define DIGEST_CMD /* Image crypto digest commands */
+